==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Uncertainty/Distribution/GumbelFactory.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  GumbelFactory.cxx
 *  @brief Factory for Gumbel distribution
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2007-05-10 16:43:31 +0200 (jeu 10 mai 2007) $
 *  Id:      $Id: GumbelFactory.cxx 434 2007-05-10 14:43:31Z dutka $
 */
#include "GumbelFactory.hxx"
#include "Gumbel.hxx"
#include "SpecFunc.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Distribution {

      typedef Model::DistributionImplementationFactory::NumericalPoint NumericalPoint;

      /* Default constructor */
      GumbelFactory::GumbelFactory()
      {
	// Initialize any other class members here
	// At last, allocate memory space if needed, but go to destructor to free it
      }

      /* Virtual constructor */
      GumbelFactory * GumbelFactory::clone() const
      {
	return new GumbelFactory(*this);
      }

      /* Here is the interface that all derived class must implement */

      GumbelFactory::DistributionImplementation * GumbelFactory::buildImplementation(const NumericalSample & sample) const throw(InvalidArgumentException, InternalException)
      {
	if (sample.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a Gumbel distribution from an empty sample";
	if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build a Gumbel distribution only from a sample of dimension 1, here dimension=" << sample.getDimension();
	NumericalScalar mu(sample.computeMean()[0]);
	NumericalScalar sigma(sample.computeStandardDeviationPerComponent()[0]);
	if (sigma <= 0.0) throw InternalException(HERE) << "Error: can build a Gumbel distribution only if sigma >= 0, here sigma=" << sigma;
	return Gumbel(mu, sigma, Gumbel::MUSIGMA).clone();
      }

    } /* namespace Distribution */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/src/Uncertainty/Distribution/GumbelFactory.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  GumbelFactory.cxx
 *  @brief Factory for Gumbel distribution
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 10:54:56 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: GumbelFactory.cxx 1261 2009-05-28 08:54:56Z dutka $
 */
#include "GumbelFactory.hxx"
#include "Gumbel.hxx"
#include "SpecFunc.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Distribution {

      typedef Model::DistributionImplementationFactory::NumericalPoint NumericalPoint;

      /* Default constructor */
      GumbelFactory::GumbelFactory()
      {
	// Initialize any other class members here
	// At last, allocate memory space if needed, but go to destructor to free it
      }

      /* Virtual constructor */
      GumbelFactory * GumbelFactory::clone() const
      {
	return new GumbelFactory(*this);
      }

      /* Here is the interface that all derived class must implement */

      GumbelFactory::DistributionImplementation * GumbelFactory::buildImplementation(const NumericalSample & sample) const throw(InvalidArgumentException, InternalException)
      {
	if (sample.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a Gumbel distribution from an empty sample";
	if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build a Gumbel distribution only from a sample of dimension 1, here dimension=" << sample.getDimension();
	NumericalScalar mu(sample.computeMean()[0]);
	NumericalScalar sigma(sample.computeStandardDeviationPerComponent()[0]);
	if (sigma <= 0.0) throw InternalException(HERE) << "Error: can build a Gumbel distribution only if sigma >= 0, here sigma=" << sigma;
	return Gumbel(mu, sigma, Gumbel::MUSIGMA).clone();
      }

      GumbelFactory::DistributionImplementation * GumbelFactory::buildImplementation(const NumericalPointCollection & parameters) const throw(InvalidArgumentException, InternalException)
      {
	try {
	  Gumbel distribution;
	  distribution.setParametersCollection(parameters);
	  return distribution.clone();
	}
	catch (InvalidArgumentException & ex)
	  {
	    throw InternalException(HERE) << "Error: cannot build a Gumbel distribution from the given parameters";
	  }
      }

      GumbelFactory::DistributionImplementation * GumbelFactory::buildImplementation() const throw(InvalidArgumentException, InternalException)
      {
	return Gumbel().clone();
      }

    } /* namespace Distribution */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
